@@ -132,7 +132,6 @@ gdk_pixbuf_animation_new_from_file (const char *filename,
 	guchar buffer [1024];
 	GdkPixbufModule *image_module;
         gchar *display_name;
-        gboolean locked = FALSE;
 
 	g_return_val_if_fail (filename != NULL, NULL);
         g_return_val_if_fail (error == NULL || *error == NULL, NULL);
@@ -206,15 +205,13 @@ gdk_pixbuf_animation_new_from_file (const char *filename,
 		if (pixbuf == NULL) {
                         g_free (display_name);
                         animation = NULL;
-                        goto out_unlock;
+                        goto out;
                 }
 
                 animation = gdk_pixbuf_non_anim_new (pixbuf);
 
                 g_object_unref (pixbuf);
 	} else {
-                locked = _gdk_pixbuf_lock (image_module);
-
 		fseek (f, 0, SEEK_SET);
 		animation = (* image_module->load_animation) (f, error);
 
@@ -241,9 +238,7 @@ gdk_pixbuf_animation_new_from_file (const char *filename,
 
         g_free (display_name);
 
- out_unlock:
-        if (locked)
-                _gdk_pixbuf_unlock (image_module);
+ out:
 	return animation;
 }
 
@@ -548,8 +543,8 @@ gdk_pixbuf_animation_iter_on_currently_loading_frame (GdkPixbufAnimationIter *it
  *
  * If this function returns %FALSE, there's no need to update the animation
  * display, assuming the display had been rendered prior to advancing;
- * if %TRUE, you need to call gdk_animation_iter_get_pixbuf() and update the
- * display with the new pixbuf.
+ * if %TRUE, you need to call gdk_pixbuf_animation_iter_get_pixbuf()
+ * and update the display with the new pixbuf.
  *
  * Returns: %TRUE if the image may need updating
  * 
